\name{coords.aniso}
\alias{coords.aniso}

%- Also NEED an `\alias' for EACH other topic documented here.

\title{(Geometric) anisotropy correction}

\description{
Transforms (rotates and shrinks) given coordinates according to the (geometric) anisotropy parameters.
}
\usage{
coords.aniso(coords, aniso.pars)
}

\arguments{
  \item{coords}{a matrix with dimention \eqn{n x 2}{n x 2} with coordinates}
  \item{aniso.pars}{a vector with two elements: the first is the
    \em{anisotropy angle} and the second is the \em{anisotropy ratio}.
    See DETAILS for the description of these elements.
  }
}

\details{
  \em{Anisotropy angle} is defined here as the azimuth angle of the
  direction greater spatial continuity, i.e. the angle betwween the
  y-axis and the direction with maximum range.

  \em{Anisotropy ratio} is defined here as the ratio between the range
  in the direction of greater and smaller continuity, i.e. the ration
  between maximum and minimum ranges. It is therefore always
  \eqn{>= 1}{>=1} grater or equal to one.
}
\value{
  A matrix with dimention \eqn{n x 2}{n x 2} with the transformed coordinates.
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo Justiniano Ribeiro Jr. <\email{paulojus@est.ufpr.br}> \cr
  Peter J. Diggle <\email{p.diggle@lancaster.ac.uk}>.
}

%\note{ ~~further notes~~ }

 
%\seealso{ ~~objects to SEE ALSO as \code{\link{~~fun~~}}, ~~~ }

\examples{
par.mf <- par()$mfrow
par(mfrow=c(2,2))
plot(c(-1.5, 1), c(-1, 1), type="n")
text(x=coords.ori[,1], y=coords.ori[,2], lab=1:4)
coords.ori <- matrix(c(0,1,1,0,0,0,1,1), ncol=2)
coordsA <- coords.aniso(coords.ori, c(0, 2))
plot(c(-1.5, 1), c(-1, 1), type="n")
text(x=coordsA[,1], y=coordsA[,2], lab=paste("A", 1:4))
coordsB <- coords.aniso(coords.ori, c(pi/2, 2))
plot(c(-1.5, 1), c(-1, 1), type="n")
text(x=coordsB[,1], y=coordsB[,2], lab=paste("B", 1:4))
coordsC <- coords.aniso(coords.ori, c((3*pi/4), 2))
plot(c(-1.5, 1), c(-1, 1), type="n")
text(x=coordsC[,1], y=coordsC[,2], lab=paste("C", 1:4)) 
par(mfrow=par.mf)
}

\keyword{spatial}
